==> helix-1.3.1-src.zip: helix-1.3.1/helix-core/src/main/java/org/apache/helix/controller/rebalancer/waged/WagedResourceWeightsProvider.java <==
package org.apache.helix.controller.rebalancer.waged;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Map;
import javax.annotation.Nullable;
import org.apache.helix.controller.dataproviders.ResourceControllerDataProvider;
import org.apache.helix.controller.rebalancer.util.WagedRebalanceUtil;
import org.apache.helix.model.IdealState;
import org.apache.helix.model.ResourceConfig;


/**
 * A weights data provider for waged resources.
 */
public class WagedResourceWeightsProvider {

  private final ResourceControllerDataProvider _clusterData;

  public WagedResourceWeightsProvider(ResourceControllerDataProvider clusterData) {
    _clusterData = clusterData;
  }

  public Map<String, Integer> getPartitionWeights(String resourceName, String partition) {
    @Nullable ResourceConfig resourceConfig = _clusterData.getResourceConfig(resourceName);
    IdealState is = _clusterData.getIdealState(resourceName);
    ResourceConfig mergedResourceConfig =
        ResourceConfig.mergeIdealStateWithResourceConfig(resourceConfig, is);

    return WagedRebalanceUtil.fetchCapacityUsage(partition, mergedResourceConfig, _clusterData.getClusterConfig());
  }
}

==> helix-1.4.2-src.zip: helix-1.4.2/helix-core/src/main/java/org/apache/helix/controller/rebalancer/waged/WagedResourceWeightsProvider.java <==
package org.apache.helix.controller.rebalancer.waged;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Map;
import javax.annotation.Nullable;
import org.apache.helix.controller.dataproviders.ResourceControllerDataProvider;
import org.apache.helix.controller.rebalancer.util.WagedRebalanceUtil;
import org.apache.helix.model.IdealState;
import org.apache.helix.model.ResourceConfig;


/**
 * A weights data provider for waged resources.
 */
public class WagedResourceWeightsProvider {

  private final ResourceControllerDataProvider _clusterData;

  public WagedResourceWeightsProvider(ResourceControllerDataProvider clusterData) {
    _clusterData = clusterData;
  }

  public Map<String, Integer> getPartitionWeights(String resourceName, String partition) {
    @Nullable ResourceConfig resourceConfig = _clusterData.getResourceConfig(resourceName);

    return WagedRebalanceUtil.fetchCapacityUsage(partition, resourceConfig, _clusterData.getClusterConfig());
  }
}
